==> haskell-httpd-shed-0.4.0.3-35-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: httpd-shed
version: 0.4.0.3
id: httpd-shed-0.4.0.3-JuQ35fz7w0TCxyftPtdR2K
key: httpd-shed-0.4.0.3-JuQ35fz7w0TCxyftPtdR2K
license: BSD-3-Clause
copyright: (c) 2009 Andy Gill
maintainer: Andy Gill
author: Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis: A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.
category: Network, Web
abi: 5b8d66ca5276cfd363437c90fac5f185
exposed: True
exposed-modules:
    Network.Shed.Httpd
import-dirs: /usr/lib/ghc-8.4.3/site-local/httpd-shed-0.4.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/httpd-shed-0.4.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/httpd-shed-0.4.0.3
hs-libraries: HShttpd-shed-0.4.0.3-JuQ35fz7w0TCxyftPtdR2K
depends:
    base-4.11.1.0 network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
haddock-interfaces: /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html: /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-httpd-shed-0.4.0.3-41-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: httpd-shed
version: 0.4.0.3
id: httpd-shed-0.4.0.3-IgIoR4bvvwK6CoGTMvMrUE
key: httpd-shed-0.4.0.3-IgIoR4bvvwK6CoGTMvMrUE
license: BSD-3-Clause
copyright: (c) 2009 Andy Gill
maintainer: Andy Gill
author: Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis: A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.
category: Network, Web
abi: f7478062d4a7d6ce163c936fc3eb937a
exposed: True
exposed-modules:
    Network.Shed.Httpd
import-dirs: /usr/lib/ghc-8.6.1/site-local/httpd-shed-0.4.0.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/httpd-shed-0.4.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/httpd-shed-0.4.0.3
hs-libraries: HShttpd-shed-0.4.0.3-IgIoR4bvvwK6CoGTMvMrUE
depends:
    base-4.12.0.0 network-2.7.0.2-2yr2pvLPehY6oGeYQ5TSho
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
haddock-interfaces: /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html: /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
